package net.wanji.utc.controller;

import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import net.wanji.common.annotation.aspect.AspectLog;
import net.wanji.common.enums.BaseEnum;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.databus.po.ManufacturerApiInfoPO;
import net.wanji.utc.dto.systemadmin.DeleteByIntegerIdListDTO;
import net.wanji.utc.dto.systemadmin.ManufacturerApiInfoInsertOrUpdateDTO;
import net.wanji.utc.dto.systemadmin.ManufacturerApiInfoListDTO;
import net.wanji.utc.service.systemadmin.ManufacturerApiInfoService;
import net.wanji.utc.vo.systemadmin.ManufacturerApiInfoVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.dao.DuplicateKeyException;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.ws.rs.core.MediaType;

/**
 * 系统管理-接口管理
 *
 * @author Kent HAN
 * @date 2022/11/24 8:32
 */

@Api(value = "系统管理-接口管理", description = "系统管理-接口管理")
@RequestMapping("/manufacturerApiInfo")
@RestController
public class ManufacturerApiController {
    @Autowired
    ManufacturerApiInfoService manufacturerApiInfoService;

    @AspectLog(description = "接口列表", operationType = BaseEnum.OperationTypeEnum.QUERY)
    @ApiOperation(value = "接口列表", notes = "接口列表", response = ManufacturerApiInfoPO.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/list",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = ManufacturerApiInfoPO.class),
    })
    public JsonViewObject list(@RequestBody ManufacturerApiInfoListDTO manufacturerApiInfoListDTO) {
        PageInfo<ManufacturerApiInfoVO> manufacturerApiInfoOutVOPageInfo =
                manufacturerApiInfoService.list(manufacturerApiInfoListDTO);
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();

        return jsonViewObject.success(manufacturerApiInfoOutVOPageInfo);
    }

    @AspectLog(description = "接口添加或修改", operationType = BaseEnum.OperationTypeEnum.QUERY)
    @ApiOperation(value = "接口添加或修改", notes = "接口添加或修改", consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/insertOrUpdate", consumes = MediaType.APPLICATION_JSON)
    public JsonViewObject insertOrUpdate(@RequestBody @Validated ManufacturerApiInfoInsertOrUpdateDTO inVO) {
        try {
            manufacturerApiInfoService.insertOrUpdate(inVO);
        } catch (DuplicateKeyException e) {
            throw new DuplicateKeyException("接口代码、接口名称、接口地址不可重复");
        }
        return JsonViewObject.newInstance().success();
    }

    @AspectLog(description = "接口删除", operationType = BaseEnum.OperationTypeEnum.QUERY)
    @ApiOperation(value = "接口删除", notes = "接口删除", consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/delete", consumes = MediaType.APPLICATION_JSON)
    public JsonViewObject delete(@RequestBody DeleteByIntegerIdListDTO inVO) {
        manufacturerApiInfoService.delete(inVO);
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();

        return jsonViewObject.success();
    }
}
